==> owlapi-api-5.0.5-sources.jar: org/semanticweb/owlapitools/builders/BaseSetBuilder.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapitools.builders;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.add;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import java.util.stream.Stream;

import javax.inject.Inject;

import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLObject;

/**
 * Abstract builder for entities.
 * 
 * @author ignazio
 * @param <T>
 *        type built
 * @param <B>
 *        builder type
 * @param <I>
 *        contained items type
 */
public abstract class BaseSetBuilder<T extends OWLObject, B, I> extends BaseBuilder<T, B> {

    protected final Set<I> items = new HashSet<>();

    /**
     * @param df
     *        data factory
     */
    @Inject
    public BaseSetBuilder(OWLDataFactory df) {
        super(df);
    }

    /**
     * @param arg
     *        item to add
     * @return builder
     */
    @SuppressWarnings("unchecked")
    public B withItem(I arg) {
        items.add(arg);
        return (B) this;
    }

    /**
     * @param arg
     *        items to add
     * @return builder
     */
    @SuppressWarnings("unchecked")
    public B withItems(Collection<? extends I> arg) {
        items.addAll(arg);
        return (B) this;
    }

    /**
     * @param arg
     *        items to add
     * @return builder
     */
    @SuppressWarnings({ "unchecked" })
    public B withItems(Stream<? extends I> arg) {
        add(items, arg);
        return (B) this;
    }

    /**
     * @param arg
     *        items to add
     * @return builder
     */
    @java.lang.SafeVarargs
    @SuppressWarnings("unchecked")
    public final B withItems(I... arg) {
        for (I i : arg) {
            items.add(i);
        }
        return (B) this;
    }
}

==> owlapi-api-5.1.9-sources.jar: org/semanticweb/owlapitools/builders/BaseSetBuilder.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapitools.builders;

import static org.semanticweb.owlapi.util.OWLAPIStreamUtils.add;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import java.util.stream.Stream;
import javax.inject.Inject;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLObject;

/**
 * Abstract builder for entities.
 *
 * @param <T> type built
 * @param <B> builder type
 * @param <I> contained items type
 * @author ignazio
 */
public abstract class BaseSetBuilder<T extends OWLObject, B, I> extends BaseBuilder<T, B> {

    protected final Set<I> items = new HashSet<>();

    /**
     * @param df data factory
     */
    @Inject
    public BaseSetBuilder(OWLDataFactory df) {
        super(df);
    }

    /**
     * @param arg item to add
     * @return builder
     */
    @SuppressWarnings("unchecked")
    public B withItem(I arg) {
        items.add(arg);
        return (B) this;
    }

    /**
     * @param arg items to add
     * @return builder
     */
    @SuppressWarnings("unchecked")
    public B withItems(Collection<? extends I> arg) {
        items.addAll(arg);
        return (B) this;
    }

    /**
     * @param arg items to add
     * @return builder
     */
    @SuppressWarnings({"unchecked"})
    public B withItems(Stream<? extends I> arg) {
        add(items, arg);
        return (B) this;
    }

    /**
     * @param arg items to add
     * @return builder
     */
    @java.lang.SafeVarargs
    @SuppressWarnings("unchecked")
    public final B withItems(I... arg) {
        for (I i : arg) {
            items.add(i);
        }
        return (B) this;
    }
}
